"use strict";

var _path = _interopRequireDefault(require("path"));

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _glob = _interopRequireDefault(require("glob"));

var _chalk = _interopRequireDefault(require("chalk"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const [processExecutor, ignoredBin, script, ...args] = process.argv;
const executor = (0, _utils.isGdScripts)() ? "ts-node" : processExecutor;

const handleSignal = result => {
  if (result.signal === "SIGKILL") {
    // eslint-disable-next-line no-console
    console.log(`The script "${script}" failed because the process exited too early. ` + "This probably means the system ran out of memory or someone called " + "`kill -9` on the process.");
  } else if (result.signal === "SIGTERM") {
    // eslint-disable-next-line no-console
    console.log(`The script "${script}" failed because the process exited too early. ` + "Someone might have called `kill` or `killall`, or the system could " + "be shutting down.");
  }

  process.exit(1);
};

const attemptResolve = (...resolveArgs) => {
  try {
    return require.resolve(...resolveArgs);
  } catch (error) {
    return null;
  }
}; // this is required to address an issue in cross-spawn
// https://github.com/kentcdodds/kcd-scripts/issues/4


const getEnv = () => Object.keys(process.env).filter(key => process.env[key] !== undefined).reduce((envCopy, key) => {
  envCopy[key] = process.env[key];
  return envCopy;
}, {
  [`SCRIPTS_${script.toUpperCase()}`]: true
});

const spawnScript = () => {
  const relativeScriptPath = _path.default.join(__dirname, "./scripts", script);

  const scriptPath = attemptResolve(relativeScriptPath);

  if (!scriptPath) {
    throw new Error(`Unknown script "${script}".`);
  }

  const result = _crossSpawn.default.sync(executor, [scriptPath, ...args], {
    stdio: "inherit",
    env: getEnv()
  });

  if (result.signal) {
    handleSignal(result);
  } else {
    process.exit(result.status);
  }
};

if (script) {
  spawnScript();
} else {
  const scriptsPath = _path.default.join(__dirname, "scripts/");

  const scriptsAvailable = _glob.default.sync(_path.default.join(__dirname, "scripts", "*")); // `glob.sync` returns paths with unix style path separators even on Windows.
  // So we normalize it before attempting to strip out the scripts path.


  const scriptsAvailableMessage = scriptsAvailable.map(_path.default.normalize).map(s => s.replace(scriptsPath, "").replace(/__tests__/, "").replace(/\.ts$/, "")).filter(Boolean).join("\n  ").trim();
  const fullMessage = `
${_chalk.default.cyan("Usage")}: 
  ${ignoredBin} [script] [--flags]

${_chalk.default.cyan("Available Scripts")}:
  ${scriptsAvailableMessage}

${_chalk.default.cyan("Options")}:
  All options depend on the script. Docs will be improved eventually, 
  but for most scripts you can assume that the args you pass will be 
  forwarded to the respective tool that's being run under the hood.

${_chalk.default.green("May the force be with you")}.
  `.trim();
  console.log(`\n${fullMessage}\n`); // eslint-disable-line no-console
}
//# sourceMappingURL=run-script.js.map