"use strict";

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _chalk = _interopRequireDefault(require("chalk"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

process.env.SCRIPT_CI = "true";
const unnecessaryArgumentsCount = 2;
const args = process.argv.slice(unnecessaryArgumentsCount);
const gdScripts = (0, _utils.isGdScripts)();
const executor = gdScripts ? "ts-node" : "gd-scripts";

const getArgsSpawn = script => gdScripts ? ["src", script, ...args] : [script, ...args];

const isTypescript = (0, _utils.hasFile)("tsconfig.json");
(0, _utils.logScriptMessage)("CI");

const resultLint = _crossSpawn.default.sync((0, _utils.resolveBin)(executor), [...getArgsSpawn("lint")], {
  stdio: "inherit"
});

const packageHasTests = (0, _utils.hasTests)();
let resultTypecheck = {
  status: 0
};
let resultTest = {
  status: 0
};

if (isTypescript) {
  resultTypecheck = _crossSpawn.default.sync((0, _utils.resolveBin)(executor), [...getArgsSpawn("typecheck")], {
    stdio: "inherit"
  });
}

if (packageHasTests) {
  resultTest = _crossSpawn.default.sync((0, _utils.resolveBin)(executor), [...getArgsSpawn("test")], {
    stdio: "inherit"
  });
}

const resultBuild = _crossSpawn.default.sync((0, _utils.resolveBin)(executor), [...getArgsSpawn("build")], {
  stdio: "inherit"
});

const finalResult = [resultLint.status, resultTest.status, resultTypecheck.status, resultBuild.status].some(x => x === 1) ? 1 : 0;
console.log(`\n${_chalk.default.cyan("CI RESULTS:")}`);

const logStatus = (script, status) => {
  console.log(`${script}${status === 0 ? _chalk.default.green("SUCCESS") : _chalk.default.red("ERROR")}`);
};

console.log();
logStatus("Lint\t   ", resultLint.status);

if (isTypescript) {
  logStatus("Typecheck  ", resultTypecheck.status);
}

if (packageHasTests) {
  logStatus("Test\t   ", resultTest.status);
}

logStatus("Build\t   ", resultBuild.status);
console.log();
process.exit(finalResult);
//# sourceMappingURL=ci.js.map