"use strict";

var _path = _interopRequireDefault(require("path"));

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _yargsParser = _interopRequireDefault(require("yargs-parser"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const unnecessaryArgumentsCount = 2;
let args = process.argv.slice(unnecessaryArgumentsCount);

const here = p => _path.default.join(__dirname, p);

const hereRelative = p => here(p).replace(process.cwd(), ".");

const parsedArgs = (0, _yargsParser.default)(args);
const useBuiltinConfig = !args.includes("--config") && !(0, _utils.hasFile)(".eslintrc") && !(0, _utils.hasFile)(".eslintrc.js") && !(0, _utils.hasPkgProp)("eslintConfig");
const config = useBuiltinConfig ? ["--config", hereRelative("../config/eslintrc.js")] : [];
const cache = args.includes("--no-cache") ? [] : ["--cache"];
const filesGiven = parsedArgs._.length > 0;
const filesToApply = filesGiven ? [] : ["."];
const extensions = ["--ext", ".js,.ts"];
const cacheLocation = ["--cache-location", "node_modules/.cache/.eslintcache"];

const isLintable = file => file.endsWith(".js") || file.endsWith(".ts");

if (filesGiven) {
  // we need to take all the flag-less arguments (the files that should be linted)
  // and filter out the ones that aren't js files. Otherwise json or css files
  // may be passed through
  args = args.filter(a => !parsedArgs._.includes(a) || isLintable(a));
}

const lintArguments = [...config, ...extensions, ...cacheLocation, ...cache, ...args, ...filesToApply];
(0, _utils.logScriptMessage)("LINT");

const result = _crossSpawn.default.sync((0, _utils.resolveBin)("eslint"), lintArguments, {
  stdio: "inherit"
});

process.exit(result.status);
//# sourceMappingURL=lint.js.map